@@ -204,9 +204,10 @@ setMethod(
     if(!inherits(g1[[which]], "ADEg")) 
       stop("superposition is only available between two ADEg")
     addi <- cbind(rbind(g1@add, rep(0, ngraph)), rep(0, ngraph + 1))
-    
     addi[which, ngraph + 1] <- 1  ## new graph superpose to which
-    ADEgS <- new(Class = "ADEgS", ADEglist = c(g1@ADEglist, g2), positions = rbind(g1@positions, g1@positions[which,]), add = addi, Call = match.call())
+    ADEglist <- g1@ADEglist
+    ADEglist[[ngraph+1]] <- g2
+    ADEgS <- new(Class = "ADEgS", ADEglist = ADEglist, positions = rbind(g1@positions, g1@positions[which,]), add = addi, Call = match.call())
     if(plot) 
       print(ADEgS)
     invisible(ADEgS)
